@@ -14,8 +14,6 @@ func TestTestifyLint(t *testing.T) {
 	t.Parallel()
 
 	for _, checker := range checkers.All() {
-		checker := checker
-
 		t.Run(checker, func(t *testing.T) {
 			t.Parallel()
 
@@ -68,14 +66,26 @@ func TestTestifyLint_NotDefaultCases(t *testing.T) {
 			dir:   "encoded-compare-issue198",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewEncodedCompare().Name()},
 		},
+		{
+			dir:   "equal-values-different-pkg",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewEqualValues().Name()},
+		},
 		{
 			dir:   "error-as-target",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewErrorIsAs().Name()},
 		},
+		{
+			dir:   "error-is-as-issue231",
+			flags: map[string]string{"enable-all": "true"},
+		},
 		{
 			dir:   "error-nil-issue95",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewErrorNil().Name()},
 		},
+		{
+			dir:   "expected-actual-issue174",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewExpectedActual().Name()},
+		},
 		{
 			dir: "expected-var-custom-pattern",
 			flags: map[string]string{
@@ -105,6 +115,15 @@ func TestTestifyLint_NotDefaultCases(t *testing.T) {
 				"enable":                        checkers.NewFormatter().Name(),
 				"formatter.check-format-string": "false",
 				"formatter.require-f-funcs":     "true",
+				"formatter.require-string-msg":  "false",
+			},
+		},
+		{
+			dir: "formatter-require-f-for-non-string-arg",
+			flags: map[string]string{
+				"disable-all":               "true",
+				"enable":                    checkers.NewFormatter().Name(),
+				"formatter.require-f-funcs": "true",
 			},
 		},
 		{
@@ -148,6 +167,10 @@ func TestTestifyLint_NotDefaultCases(t *testing.T) {
 			dir:   "require-error-skip-logic",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewRequireError().Name()},
 		},
+		{
+			dir:   "suite-extra-assert-call-issue176",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewSuiteExtraAssertCall().Name()},
+		},
 		{
 			dir: "suite-require-extra-assert-call",
 			flags: map[string]string{
@@ -159,8 +182,6 @@ func TestTestifyLint_NotDefaultCases(t *testing.T) {
 	}
 
 	for _, tt := range cases {
-		tt := tt
-
 		t.Run(tt.dir, func(t *testing.T) {
 			t.Parallel()
 
