@@ -1,7 +1,6 @@
 package gomoddirectives
 
 import (
-	"os"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -9,15 +8,7 @@ import (
 )
 
 func TestGetModuleFile(t *testing.T) {
-	wd, err := os.Getwd()
-	require.NoError(t, err)
-
-	t.Cleanup(func() {
-		_ = os.Chdir(wd)
-	})
-
-	err = os.Chdir("./testdata/replace/")
-	require.NoError(t, err)
+	t.Chdir("./testdata/replace/")
 
 	file, err := GetModuleFile()
 	require.NoError(t, err)
