@@ -298,7 +298,7 @@ func applyDiffsAndCompare(filename string, original, want []byte, edits []diff.E
 	}
 	fixed, err := format.Source(fixedBytes)
 	if err != nil {
-		return fmt.Errorf("%s: error formatting resulting source: %v\n%s", filename, err, fixed)
+		return fmt.Errorf("%s: error formatting resulting source: %v\n%s", filename, err, fixedBytes)
 	}
 
 	want, err = format.Source(want)
@@ -425,7 +425,7 @@ func Run(t Testing, dir string, a *analysis.Analyzer, patterns ...string) []*Res
 
 		// Construct the legacy result.
 		results = append(results, &Result{
-			Pass:        internal.Pass(act),
+			Pass:        internal.ActionPass(act), // may be nil
 			Diagnostics: act.Diagnostics,
 			Facts:       facts,
 			Result:      act.Result,
@@ -448,12 +448,12 @@ func Run(t Testing, dir string, a *analysis.Analyzer, patterns ...string) []*Res
 type Result struct {
 	Action *checker.Action
 
-	// legacy fields
+	// legacy fields (do not use)
 	Facts       map[types.Object][]analysis.Fact // nil key => package fact
-	Pass        *analysis.Pass
-	Diagnostics []analysis.Diagnostic // see Action.Diagnostics
-	Result      any                   // see Action.Result
-	Err         error                 // see Action.Err
+	Pass        *analysis.Pass                   // nil => action not executed
+	Diagnostics []analysis.Diagnostic            // see Action.Diagnostics
+	Result      any                              // see Action.Result
+	Err         error                            // see Action.Err
 }
 
 // loadPackages uses go/packages to load a specified packages (from source, with
@@ -527,7 +527,7 @@ func check(t Testing, gopath string, act *checker.Action) {
 
 		// Any comment starting with "want" is treated
 		// as an expectation, even without following whitespace.
-		if rest := strings.TrimPrefix(text, "want"); rest != text {
+		if rest, ok := strings.CutPrefix(text, "want"); ok {
 			lineDelta, expects, err := parseExpectations(rest)
 			if err != nil {
 				t.Errorf("%s:%d: in 'want' comment: %s", filename, linenum, err)
@@ -575,11 +575,11 @@ func check(t Testing, gopath string, act *checker.Action) {
 	files := act.Package.OtherFiles
 
 	// Hack: these two analyzers need to extract expectations from
-	// all configurations, so include the files are are usually
+	// all configurations, so include the files are usually
 	// ignored. (This was previously a hack in the respective
 	// analyzers' tests.)
 	if act.Analyzer.Name == "buildtag" || act.Analyzer.Name == "directive" {
-		files = append(files[:len(files):len(files)], act.Package.IgnoredFiles...)
+		files = slices.Concat(files, act.Package.IgnoredFiles)
 	}
 
 	for _, filename := range files {
@@ -590,7 +590,7 @@ func check(t Testing, gopath string, act *checker.Action) {
 		}
 		filename := sanitize(gopath, filename)
 		linenum := 0
-		for _, line := range strings.Split(string(data), "\n") {
+		for line := range strings.SplitSeq(string(data), "\n") {
 			linenum++
 
 			// Hack: treat a comment of the form "//...// want..."
