@@ -10,10 +10,9 @@ import (
 
 	"golang.org/x/tools/go/analysis"
 	"golang.org/x/tools/go/analysis/passes/inspect"
+	"golang.org/x/tools/go/analysis/passes/internal/gofixdirective"
 	"golang.org/x/tools/go/ast/inspector"
 	"golang.org/x/tools/internal/analysisinternal"
-	"golang.org/x/tools/internal/astutil/cursor"
-	"golang.org/x/tools/internal/gofix/findgofix"
 )
 
 //go:embed doc.go
@@ -28,7 +27,7 @@ var Analyzer = &analysis.Analyzer{
 }
 
 func run(pass *analysis.Pass) (any, error) {
-	root := cursor.Root(pass.ResultOf[inspect.Analyzer].(*inspector.Inspector))
-	findgofix.Find(pass, root, nil)
+	root := pass.ResultOf[inspect.Analyzer].(*inspector.Inspector).Root()
+	gofixdirective.Find(pass, root, nil)
 	return nil, nil
 }
