@@ -84,6 +84,9 @@ type Finder struct {
 // info.{Defs,Uses,Selections,Types} must have been populated by the
 // type-checker.
 func (f *Finder) Find(info *types.Info, files []*ast.File) {
+	if info.Defs == nil || info.Uses == nil || info.Selections == nil || info.Types == nil {
+		panic("Finder.Find: one of info.{Defs,Uses,Selections.Types} is not populated")
+	}
 	if f.Result == nil {
 		f.Result = make(map[Constraint]bool)
 	}
@@ -201,8 +204,10 @@ func (f *Finder) call(sig *types.Signature, args []ast.Expr) {
 func (f *Finder) builtin(obj *types.Builtin, sig *types.Signature, args []ast.Expr) {
 	switch obj.Name() {
 	case "make", "new":
-		// skip the type operand
-		for _, arg := range args[1:] {
+		for i, arg := range args {
+			if i == 0 && f.info.Types[arg].IsType() {
+				continue // skip the type operand
+			}
 			f.expr(arg)
 		}
 
